==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/ToolActionMenuBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
/**
 * @hidden
 */
var ToolActionMenuBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionMenuBaseDescriptionMetadata, _super);
    function ToolActionMenuBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionMenuBaseDescriptionMetadata.b = function (a) {
        if (ToolActionMenuBaseDescriptionMetadata.a == null) {
            ToolActionMenuBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionMenuBaseDescriptionMetadata.c(ToolActionMenuBaseDescriptionMetadata.a);
        }
        if (a.j(ToolActionMenuBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionMenuBaseDescriptionMetadata.a);
    };
    ToolActionMenuBaseDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("Actions", "Collection:ToolAction:ToolActionCollection:ToolAction");
    };
    ToolActionMenuBaseDescriptionMetadata.d = function (a) {
        ToolActionMenuBaseDescriptionMetadata.b(a);
        a.z("ToolActionMenuBase", ToolActionMenuBaseDescriptionMetadata.a);
    };
    ToolActionMenuBaseDescriptionMetadata.$t = markType(ToolActionMenuBaseDescriptionMetadata, 'ToolActionMenuBaseDescriptionMetadata');
    ToolActionMenuBaseDescriptionMetadata.a = null;
    return ToolActionMenuBaseDescriptionMetadata;
}(Base));
export { ToolActionMenuBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ToolActionMenuBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
/**
 * @hidden
 */
var ToolActionMenuBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ToolActionMenuBaseDescriptionMetadata, _super);
    function ToolActionMenuBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionMenuBaseDescriptionMetadata.b = function (a) {
        if (ToolActionMenuBaseDescriptionMetadata.a == null) {
            ToolActionMenuBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionMenuBaseDescriptionMetadata.c(ToolActionMenuBaseDescriptionMetadata.a);
        }
        if (a.k(ToolActionMenuBaseDescriptionMetadata.a)) {
            return;
        }
        a.aa(ToolActionMenuBaseDescriptionMetadata.a);
    };
    ToolActionMenuBaseDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("Actions", "Collection:ToolAction:ToolActionCollection:ToolAction");
    };
    ToolActionMenuBaseDescriptionMetadata.d = function (a) {
        ToolActionMenuBaseDescriptionMetadata.b(a);
        a.ab("ToolActionMenuBase", ToolActionMenuBaseDescriptionMetadata.a);
    };
    ToolActionMenuBaseDescriptionMetadata.$t = markType(ToolActionMenuBaseDescriptionMetadata, 'ToolActionMenuBaseDescriptionMetadata');
    ToolActionMenuBaseDescriptionMetadata.a = null;
    return ToolActionMenuBaseDescriptionMetadata;
}(Base));
export { ToolActionMenuBaseDescriptionMetadata };
